<?php

include_once("searchtwitter.php");
include_once("recent_activity.php");
include_once("count_tweets.php");

/**
 * EDUtwitter: Block for Moodle 2.2.1
 * 
 * 
 * @package  EDUtwitter
 * @author   David Romero Santos <david.romerosantos@alum.uca.es>
 * @license  http://opensource.org/licenses/gpl-license.php GNU Public License
 * @link     https://forja.rediris.es/projects/cusl6-edutweets/
 */
class block_edutwitter extends block_base {
    public function init() {
        $this->title = get_string('edutwitter', 'block_edutwitter');
    }
    public function get_content() {
        global $COURSE, $DB;

        if ($this->content !== null) {
            return $this->content;
        }

        /** 
        * If the block is configured show the search on Twitter
        */
        if(isset($this->config->course)&&isset($this->config->name)&&isset($this->config->consumerkey)&&isset($this->config->consumersecret)&&isset($this->config->oauthtoken)&&isset($this->config->oauthsecret)&&isset($this->config->search_term)){
        searchtwitter($this);      
        
        /** 
        * Links to the forms for the footer
        */
        $url = new moodle_url('/blocks/edutwitter/view_sendtweet.php', array('blockid' => $this->instance->id, 'courseid' => $COURSE->id, 'consumerkey' => $this->config->consumerkey, 'consumersecret' => $this->config->consumersecret, 'oauthtoken' => $this->config->oauthtoken, 'oauthsecret' => $this->config->oauthsecret, 'search_term' => $this->config->search_term));

        $urlestatistics = new moodle_url('/blocks/edutwitter/view_statistics.php', array('blockid' => $this->instance->id, 'courseid' => $COURSE->id, 'consumerkey' => $this->config->consumerkey, 'consumersecret' => $this->config->consumersecret, 'oauthtoken' => $this->config->oauthtoken, 'oauthsecret' => $this->config->oauthsecret, 'search_term' => $this->config->search_term));

        $urlsubmit = new moodle_url('/blocks/edutwitter/view_submit.php', array('blockid' => $this->instance->id, 'courseid' => $COURSE->id));

        /**
        * Check if the user is allowed to send tweets
        * (admin and teachers can, students and guests can't)
        */
        $context = get_context_instance(CONTEXT_COURSE, $COURSE->id);
        $capability = has_capability('moodle/course:viewhiddenactivities',$context);
        if($capability){
            $this->content->footer = "<a href=$url>".get_string('send_tweet', 'block_edutwitter')."</a><br><a href=$urlestatistics>".get_string('url_statistics', 'block_edutwitter')."</a><br><a href=$urlsubmit>".get_string('send_user_twitter', 'block_edutwitter')."</a>";
        } else {
            $this->content->footer = html_writer::link($urlsubmit, get_string('addpage_submit', 'block_edutwitter'));
        }
        
        } else {
            $this->content->text=get_string('fill_config', 'block_edutwitter');
        }

        return $this->content;
    }
    public function specialization() { //method is called as soon as posible
        if (!empty($this->config->title)) {
            $this->title = $this->config->title;
        } else {
            $this->config->title = 'EDUtwitter';
        }

        if (empty($this->config->text)) {
            $this->config->text = get_string('welcome', 'block_edutwitter');
        }
    }
    /** 
    * This function will be executed with the Moodle's script cron.php
    * Publish recent activity and count tweets for the statistics
    */
    public function cron() {
        global $DB;
        mtrace('Edutwitter at cron');
    
        $instances = $DB->get_records('block_instances', array('blockname'=>'edutwitter'));

        foreach($instances as $instance) {
            $block = block_instance('edutwitter', $instance);
            
            /** 
            * Variables needed for the Twitter API
            */
            $name=$block->config->name;
            $consumerkey=$block->config->consumerkey;
            $consumersecret=$block->config->consumersecret;
            $oauthtoken=$block->config->oauthtoken;
            $oauthsecret=$block->config->oauthsecret;
            $language=$block->config->language;
        
            $settings = array('oauth_access_token' => $oauthtoken, 'oauth_access_token_secret' => $oauthsecret, 'consumer_key' => $consumerkey, 'consumer_secret' => $consumersecret);

            if(isset($block->config->course)){

                $course = $DB->get_record('course', array('id'=>$block->config->course));
                
                /**
                * If this is the first execution,
                * create the record for the database and create the list on Twitter's account
                */
                if($DB->count_records('block_edutwitter_params',array('courseid'=>$course->id))==0){
                    $record = new stdClass();
                    $record->time_recent = time();
                    $record->time_count = time();
                    $record->last_tweet = 0;
                    $record->courseid = $course->id;
                    if(!$DB->insert_record('block_edutwitter_params', $record)){
                        print_error('inserterror', 'block_edutwitter_params');
                    }
                    $url = 'https://api.twitter.com/1.1/lists/create.json';
                    $requestMethod = 'POST';
                    if($language == '1'){
                        $postfields = array('name' => 'Alumnos'.$course->id, 'mode' => 'private', 'description' => 'Alumnos del curso '.$course->id); 
                    } else {
                        $postfields = array('name' => 'Students'.$course->id, 'mode' => 'private', 'description' => 'Enrolled students '.$course->id); 
                    }
                    $tweet = new TwitterAPIExchange($settings);
                    $tweet->buildOauth($url, $requestMethod)
                          ->setPostfields($postfields)
                          ->performRequest();
                    if($language == '1'){
                        mtrace('Lista Alumnos'.$course->id.' creada para el curso '.$course->id);
                    } else {
                        mtrace('List Students'.$course->id.' create for course '.$course->id);
                    }
                }

                /**
                * If checked publish recent activity on Twitter
                * else update the time
                */
                if($block->config->recent_activity == true){
                    recent_activity($course, $block);
                }else{
                    $record = $DB->get_record('block_edutwitter_params', array('courseid'=>$course->id));
                    $record->time_recent = time();
                    $DB->update_record('block_edutwitter_params', $record);
                }

                /**
                * If checked counts student's tweets for statistics
                * else update the time
                */
                if($block->config->statistics == true){
                    count_tweets($course,$block);
                }else{
                    $record_time = $DB->get_record('block_edutwitter_params', array('courseid'=>$course->id));
                    $record_time->time_count = time();
                    $DB->update_record('block_edutwitter_params', $record_time);
                }
            }
        }
        
        mtrace('EDUtwitter finished');
        return true;
    }
}
