<?php
/**
 * EDUtwitter: Block for Moodle 2.2.1
 * 
 * 
 * @package  EDUtwitter
 * @author   David Romero Santos <david.romerosantos@alum.uca.es>
 * @license  http://opensource.org/licenses/gpl-license.php GNU Public License
 * @link     https://forja.rediris.es/projects/cusl6-edutweets/
 */

require_once('TwitterAPIExchange.php');


/**
* Count the student's tweets with the course's hashtag since last execution
* 
* @param Course $course
* @param Block Instance $block
*/
function count_tweets($course, $block) {

    global $DB;

    /**
    * Get the last execution
    */
    $record_time = $DB->get_record('block_edutwitter_params', array('courseid'=>$course->id));
    $timestart=$record_time->time_count;


    /** 
    * Variables needed for the Twitter API
    */
    $name=$block->config->name;
    $consumerkey=$block->config->consumerkey;
    $consumersecret=$block->config->consumersecret;
    $oauthtoken=$block->config->oauthtoken;
    $oauthsecret=$block->config->oauthsecret;
    if($block->config->search_term[0] == '#'){
        $search_term=$block->config->search_term;
    } else {
        $search_term='#'.$block->config->search_term;
    }
    $language=$block->config->language;

    $settings = array('oauth_access_token' => $oauthtoken, 'oauth_access_token_secret' => $oauthsecret, 'consumer_key' => $consumerkey, 'consumer_secret' => $consumersecret);
    

    /** 
    * Insert in the list new students
    */
    $records = $DB->get_recordset('block_edutwitter_users', array('courseid' => $course->id, 'list_twitter' => '0'));
    foreach($records as $record){
        $url = 'https://api.twitter.com/1.1/lists/members/create.json';
        $requestMethod = 'POST';
        if($language == '1'){
            $postfields = array('slug' => 'Alumnos'.$course->id, 'owner_screen_name' => $name, 'screen_name' => $record->twitteruser);
        } else {
            $postfields = array('slug' => 'Students'.$course->id, 'owner_screen_name' => $name, 'screen_name' => $record->twitteruser);
        }
        $tweet = new TwitterAPIExchange($settings);
        $tweet->buildOauth($url, $requestMethod)
              ->setPostfields($postfields)
              ->performRequest();
        if($language == '1'){
            mtrace('El alumno '.$record->username.' se ha añadido a la lista del curso '.$course->id);
        } else {
            mtrace('Student '.$record->username.' added to the list of course '.$course->id);
        }
        $record->list_twitter = '1';
        $DB->update_record('block_edutwitter_users', $record);
    }
    $records->close();

    /** 
    * Get tweets of the list since the last checked
    * Identify the course's hashtag and increases the counter of the author
    */
    $registro = $DB->get_record('block_edutwitter_params',array('courseid'=>$course->id));
    $url = 'https://api.twitter.com/1.1/lists/statuses.json';
    $requestMethod = 'GET';
    if($language == '1'){
        if($registro->last_tweet==0){
            $getfield = '?owner_screen_name='.$name.'&slug=Alumnos'.$course->id;
        }else{
            $getfield = '?owner_screen_name='.$name.'&since_id='.$registro->last_tweet.'&slug=Alumnos'.$course->id;
        }
    } else {
        if($registro->last_tweet==0){
            $getfield = '?owner_screen_name='.$name.'&slug=Students'.$course->id;
        }else{
            $getfield = '?owner_screen_name='.$name.'&since_id='.$registro->last_tweet.'&slug=Students'.$course->id;
        }
    }
    
    $tweet = new TwitterAPIExchange($settings);
    $response = $tweet->setGetfield($getfield)
                      ->buildOauth($url, $requestMethod)
                      ->performRequest();
    $salida = json_decode($response);
    if((!empty($salida)) && ($salida->errors[0]->code != '34')){
        $registro->last_tweet = $salida[0]->id_str;
        $DB->update_record('block_edutwitter_params', $registro);
            foreach($salida as $mensaje){
                $control = 0;
                foreach($mensaje->entities->hashtags as $hashtag){
                    if($hashtag->text == substr($search_term,1)){
                        $control = 1;
                    }
                }
                if($control == 1){
                    $usuario = $mensaje->user->screen_name;
                    if($DB->record_exists('block_edutwitter_users', array('twitteruser' => $usuario, 'courseid' => $course->id))){
                        $record = $DB->get_record('block_edutwitter_users', array('twitteruser' => $usuario, 'courseid' => $course->id));
                        $record->numbertweets++;
                        $DB->update_record('block_edutwitter_users', $record);
                    }
                }
            }
    }

    /** 
    * Update last execution of count_tweets function for this course
    */
    $record_time = $DB->get_record('block_edutwitter_params', array('courseid'=>$course->id));
    $record_time->time_count = time();
    $DB->update_record('block_edutwitter_params', $record_time);
}
