<?php

/** This file has been modified by David Romero Santos using Twitter Search Block's code
*
* Twitter Search Block for Moodle is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
* Twitter Search Block for Moodle is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with Moodle.  If not, see <http://www.gnu.org/licenses/>.
*
* Copyright Kevin Hughes 2011
* Copyright David Romero Santos 2013
*/

require_once('TwitterAPIExchange.php');

/**
* Search the course's hashtag on Twitter and show the result on the block
* 
* @param block_edutwitter Instance $block
* 
*/
function searchtwitter($block)
{
    $output = "";
    /** 
    * Check the hashtag and the parameters
    */
    if(isset($block->config->search_term)){
        if($block->config->search_term[0] == '#'){
        $search_term=$block->config->search_term;
        } else {
            $search_term='#'.$block->config->search_term;
        }
    } else {
        $search_term="#moodle";
    }
    $numtweets = (isset($block->config->numtweets)) ? $block->config->numtweets : 5;
    $numtweets++;
    $username = (isset($block->config->show_usernames)) ? $block->config->show_usernames : true;
    $realname = (isset($block->config->show_names)) ? $block->config->show_names : true;
    $image = (isset($block->config->show_images)) ? $block->config->show_images : true;

    /** 
    * Variables needed for the Twitter API
    */
    $consumerkey=$block->config->consumerkey;
    $consumersecret=$block->config->consumersecret;
    $oauthtoken=$block->config->oauthtoken;
    $oauthsecret=$block->config->oauthsecret;

    $settings = array('oauth_access_token' => $oauthtoken, 'oauth_access_token_secret' => $oauthsecret, 'consumer_key' => $consumerkey, 'consumer_secret' => $consumersecret);

    /** 
    * Make the request to Twitter
    */
    $url = 'https://api.twitter.com/1.1/search/tweets.json';
    $requestMethod = 'GET';
    $getfield = '?q='.$search_term.'&result_type=mixed&count='.$numtweets;
    $tweet = new TwitterAPIExchange($settings);
    $response = $tweet->setGetfield($getfield)
                      ->buildOauth($url, $requestMethod)
                      ->performRequest();
    $salida = json_decode($response);
     
    /** 
    * List each status
    */
    if(!empty($salida->statuses)){
        $output .= "<ul class='block_twitter_search_tweets'>";
        foreach ($salida->statuses as $mensaje) {
            $output .= "<li class='tweet'>";
            $author = $mensaje->user->screen_name;
            $author_img = $mensaje->user->profile_image_url;
            $authorname = $mensaje->user->name;
            $authorlink = 'https://twitter.com/'.$author;
            if (($username || $realname) == false)
            {
                // do nothing!
            }
            elseif ($username == false) {
                // we're assuming that real name is in the las parentheses (pe: SearchMoodle (Search Moodle Extension))
                $authorname = substr($authorname, strrpos($authorname, '(')+1, strrpos($authorname, ')')-(strrpos($authorname, '(')+1));
            }
            elseif ($realname == false) {
                // we take the first part of string, before the last parentheses
                $authorname = substr($authorname, 0, strrpos($authorname, '('));
            }
            if ($image == true){
                $output .= "<img src='$author_img' />";
            }
            $output .= "<a href='$authorlink'>$authorname</a>: ";
            $output .= format_text($mensaje->text, FORMAT_HTML);
            $output .= "</li>";
        } 
        $block->content = new stdClass;
        $block->title = $search_term . get_string('on_twitter', 'block_edutwitter');
        $block->content->text = $output;
    } else {
            $block->content = new stdClass;
            $block->content->text = get_string('not_found', 'block_edutwitter');
        }
}
